@@ -1,7 +1,7 @@
 // qjackctlConnect.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -202,7 +202,11 @@ void qjackctlPortItem::setHilite ( bool bHilite )
 	}
 
 	// Set the new color.
-	const QPalette& pal = QTreeWidgetItem::treeWidget()->palette();
+	QTreeWidget *pTreeWidget = QTreeWidgetItem::treeWidget();
+	if (pTreeWidget == NULL)
+		return;
+
+	const QPalette& pal = pTreeWidget->palette();
 	QTreeWidgetItem::setTextColor(0, m_bHilite
 		? (pal.base().color().value() < 0x7f ? Qt::cyan : Qt::blue)
 		: pal.text().color());
@@ -363,7 +367,11 @@ void qjackctlClientItem::setHilite ( bool bHilite )
 		m_iHilite--;
 
 	// Set the new color.
-	const QPalette& pal = QTreeWidgetItem::treeWidget()->palette();
+	QTreeWidget *pTreeWidget = QTreeWidgetItem::treeWidget();
+	if (pTreeWidget == NULL)
+		return;
+
+	const QPalette& pal = pTreeWidget->palette();
 	QTreeWidgetItem::setTextColor(0, m_iHilite > 0
 		? (pal.base().color().value() < 0x7f ? Qt::darkCyan : Qt::darkBlue)
 		: pal.text().color());
@@ -415,9 +423,19 @@ qjackctlClientList::qjackctlClientList (
 
 // Default destructor.
 qjackctlClientList::~qjackctlClientList (void)
+{
+	clear();
+}
+
+
+// Do proper contents cleanup.
+void qjackctlClientList::clear (void)
 {
 	qDeleteAll(m_clients);
 	m_clients.clear();
+
+	if (m_pListView)
+		m_pListView->clear();
 }
 
 
@@ -736,10 +754,14 @@ void qjackctlClientListView::setAliases ( qjackctlConnectAlias *pAliases, bool b
 		if (m_pAliases) {
 			pClientItem->setText(0,
 				m_pAliases->clientAlias(pClientItem->clientName()));
+		} else {
+			pClientItem->setText(0,
+				pClientItem->clientName());
+		}
+		if (m_pAliases && m_bRenameEnabled) {
 			pClientItem->setFlags(
 				pClientItem->flags() |  Qt::ItemIsEditable);
 		} else {
-			pClientItem->setText(0, pClientItem->clientName());
 			pClientItem->setFlags(
 				pClientItem->flags() & ~Qt::ItemIsEditable);
 		}
@@ -756,10 +778,14 @@ void qjackctlClientListView::setAliases ( qjackctlConnectAlias *pAliases, bool b
 			if (m_pAliases) {
 				pPortItem->setText(0, m_pAliases->portAlias(
 					pPortItem->clientName(), pPortItem->portName()));
-				pPortItem->setFlags(
-					pClientItem->flags() |  Qt::ItemIsEditable);
 			} else {
-				pPortItem->setText(0, pPortItem->portName());
+				pPortItem->setText(0,
+					pPortItem->portName());
+			}
+			if (m_pAliases && m_bRenameEnabled) {
+				pPortItem->setFlags(
+					pPortItem->flags() |  Qt::ItemIsEditable);
+			} else {
 				pPortItem->setFlags(
 					pPortItem->flags() & ~Qt::ItemIsEditable);
 			}
@@ -813,6 +839,7 @@ void qjackctlClientListView::renamedSlot (void)
 		if (sText.isEmpty())
 			pPortItem->setText(0, pPortItem->portName());
 	}
+
 	m_pConnectView->setDirty(true);
 }
 
@@ -1316,6 +1343,7 @@ int qjackctlConnectView::iconSize (void) const
 void qjackctlConnectView::setDirty ( bool bDirty )
 {
 	m_bDirty = bDirty;
+
 	if (bDirty)
 		emit contentsChanged();
 }
@@ -1819,8 +1847,8 @@ void qjackctlConnect::updateContents ( bool bClear )
 	if (startMutex()) {
 		// Do we do a complete rebuild?
 		if (bClear) {
-			(m_pOClientList->listView())->clear();
-			(m_pIClientList->listView())->clear();
+			m_pOClientList->clear();
+			m_pIClientList->clear();
 			updateIconPixmaps();
 		}
 		// Add (newer) client:ports and respective connections...
