@@ -1,7 +1,7 @@
 // qjackctlConnect.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -168,8 +168,6 @@ private:
 // Jack client list.
 class qjackctlClientList : public QObject
 {
-	Q_OBJECT
-
 public:
 
 	// Constructor.
@@ -177,6 +175,9 @@ public:
 	// Default destructor.
 	~qjackctlClientList();
 
+	// Do proper contents cleanup.
+	void clear();
+
 	// Client list primitive methods.
 	void addClient(qjackctlClientItem *pClient);
 	void removeClient(qjackctlClientItem *pClient);
