@@ -334,9 +334,6 @@ void qjackctlMessagesStatusForm::keyPressEvent ( QKeyEvent *pKeyEvent )
 		QWidget::keyPressEvent(pKeyEvent);
 		break;
 	}
-
-	// Make sure we've get focus back...
-	QWidget::setFocus();
 }
 
 
