@@ -1,7 +1,7 @@
 // qjackctlPatchbay.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -188,14 +188,6 @@ public:
 	// Socket aesthetics accessors.
 	const QString& socketCaption() const;
 
-	// JACK client accessors.
-	void setJackClient(jack_client_t *pJackClient);
-	jack_client_t *jackClient() const;
-
-	// ALSA sequencer accessors.
-	void setAlsaSeq(snd_seq_t *pAlsaSeq);
-	snd_seq_t *alsaSeq() const;
-
 	// Socket list cleaner.
 	void clear();
 
@@ -228,8 +220,6 @@ private:
 	qjackctlSocketListView *m_pListView;
 	bool m_bReadable;
 	QString  m_sSocketCaption;
-	jack_client_t *m_pJackClient;
-	snd_seq_t *m_pAlsaSeq;
 
 	QPixmap *m_apPixmaps[QJACKCTL_XPM_PIXMAPS];
 
@@ -438,14 +428,6 @@ public:
 	void loadRack(qjackctlPatchbayRack *pPatchbayRack);
 	void saveRack(qjackctlPatchbayRack *pPatchbayRack);
 
-	// JACK client property accessors.
-	void setJackClient(jack_client_t *pJackClient);
-	jack_client_t *jackClient() const;
-
-	// ALSA sequencer property accessors.
-	void setAlsaSeq(snd_seq_t *pAlsaSeq);
-	snd_seq_t *alsaSeq() const;
-
 public slots:
 
 	// Complete contents refreshner.
@@ -456,6 +438,9 @@ public slots:
 	bool disconnectSelected();
 	bool disconnectAll();
 
+	// Expand all socket items.
+	void expandAll();
+
 	// Complete patchbay clearer.
 	void clear();
 
