@@ -1,7 +1,7 @@
 // qjackctlSetupForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2012, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -134,7 +134,7 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.AudioComboBox,
 		SIGNAL(highlighted(int)),
 		SLOT(changeAudio(int)));
-	QObject::connect(m_ui.ServerComboBox,
+	QObject::connect(m_ui.ServerPrefixComboBox,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(settingsChanged()));
 	QObject::connect(m_ui.ServerNameComboBox,
@@ -233,6 +233,9 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.PortMaxComboBox,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(settingsChanged()));
+	QObject::connect(m_ui.ServerSuffixComboBox,
+		SIGNAL(editTextChanged(const QString&)),
+		SLOT(settingsChanged()));
 
 	QObject::connect(m_ui.StartupScriptCheckBox,
 		SIGNAL(stateChanged(int)),
@@ -373,6 +376,9 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.StartJackCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
+	QObject::connect(m_ui.StopJackCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(optionsChanged()));
 	QObject::connect(m_ui.QueryCloseCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
@@ -472,11 +478,12 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_iDirtySetup++;
 
 	// Load combo box history...
-	m_pSetup->loadComboBoxHistory(m_ui.ServerComboBox);
+	m_pSetup->loadComboBoxHistory(m_ui.ServerPrefixComboBox);
 	m_pSetup->loadComboBoxHistory(m_ui.ServerNameComboBox);
 	m_pSetup->loadComboBoxHistory(m_ui.InterfaceComboBox);
 	m_pSetup->loadComboBoxHistory(m_ui.InDeviceComboBox);
 	m_pSetup->loadComboBoxHistory(m_ui.OutDeviceComboBox);
+	m_pSetup->loadComboBoxHistory(m_ui.ServerSuffixComboBox);
 	m_pSetup->loadComboBoxHistory(m_ui.StartupScriptShellComboBox);
 	m_pSetup->loadComboBoxHistory(m_ui.PostStartupScriptShellComboBox);
 	m_pSetup->loadComboBoxHistory(m_ui.ShutdownScriptShellComboBox);
@@ -585,6 +592,7 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 
 	// Other misc options...
 	m_ui.StartJackCheckBox->setChecked(m_pSetup->bStartJack);
+	m_ui.StopJackCheckBox->setChecked(m_pSetup->bStopJack);
 	m_ui.QueryCloseCheckBox->setChecked(m_pSetup->bQueryClose);
 	m_ui.KeepOnTopCheckBox->setChecked(m_pSetup->bKeepOnTop);
 	m_ui.SystemTrayCheckBox->setChecked(m_pSetup->bSystemTray);
@@ -653,7 +661,7 @@ void qjackctlSetupForm::changePreset ( const QString& sPreset )
 	// Load Settings...
 	qjackctlPreset preset;
 	if (m_pSetup->loadPreset(preset, sPreset)) {
-		setComboBoxCurrentText(m_ui.ServerComboBox, preset.sServer);
+		setComboBoxCurrentText(m_ui.ServerPrefixComboBox, preset.sServerPrefix);
 		setComboBoxCurrentText(m_ui.ServerNameComboBox,
 			preset.sServerName.isEmpty()
 			? m_pSetup->sDefPresetName
@@ -707,6 +715,7 @@ void qjackctlSetupForm::changePreset ( const QString& sPreset )
 		setComboBoxCurrentText(m_ui.MidiDriverComboBox,
 			preset.sMidiDriver);
 #endif
+		setComboBoxCurrentText(m_ui.ServerSuffixComboBox, preset.sServerSuffix);
 		// Reset dirty flag.
 		m_iDirtySettings = 0;
 	}
@@ -723,7 +732,7 @@ bool qjackctlSetupForm::savePreset ( const QString& sPreset )
 
 	// Unload settings.
 	qjackctlPreset preset;
-	preset.sServer      = m_ui.ServerComboBox->currentText();
+	preset.sServerPrefix = m_ui.ServerPrefixComboBox->currentText();
 	preset.sServerName  = m_ui.ServerNameComboBox->currentText();
 	preset.bRealtime    = m_ui.RealtimeCheckBox->isChecked();
 	preset.bSoftMode    = m_ui.SoftModeCheckBox->isChecked();
@@ -758,6 +767,7 @@ bool qjackctlSetupForm::savePreset ( const QString& sPreset )
 #ifdef CONFIG_JACK_MIDI
 	preset.sMidiDriver  = m_ui.MidiDriverComboBox->currentText();
 #endif
+	preset.sServerSuffix = m_ui.ServerSuffixComboBox->currentText();
 	if (preset.sServerName == m_pSetup->sDefPresetName)
 		preset.sServerName.clear();
 	if (preset.sInterface == m_pSetup->sDefPresetName)
@@ -933,22 +943,16 @@ void qjackctlSetupForm::changeDriverAudio ( const QString& sDriver, int iAudio )
 	if (!bEnabled)
 		setComboBoxCurrentText(m_ui.OutDeviceComboBox, m_pSetup->sDefPresetName);
 
-	m_ui.InChannelsTextLabel->setEnabled(bInEnabled
-		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_PLAYBACK));
+	m_ui.InOutChannelsTextLabel->setEnabled(bInEnabled || (bAlsa || bFirewire));
 	m_ui.InChannelsSpinBox->setEnabled(bInEnabled
 		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_PLAYBACK));
-
-	m_ui.OutChannelsTextLabel->setEnabled(bOutEnabled
-		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_CAPTURE));
 	m_ui.OutChannelsSpinBox->setEnabled(bOutEnabled
 		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_CAPTURE));
 
-	m_ui.InLatencyTextLabel->setEnabled((bInEnabled && !bNet)
-		|| ((bAlsa || bFreebob || bFirewire) && iAudio != QJACKCTL_PLAYBACK));
+	m_ui.InOutLatencyTextLabel->setEnabled((bInEnabled && !bNet)
+		|| (bAlsa || bFreebob || bFirewire));
 	m_ui.InLatencySpinBox->setEnabled((bInEnabled && !bNet)
 		|| ((bAlsa || bFreebob || bFirewire) && iAudio != QJACKCTL_PLAYBACK));
-	m_ui.OutLatencyTextLabel->setEnabled((bOutEnabled && !bNet)
-		|| ((bAlsa || bFreebob || bFirewire) && iAudio != QJACKCTL_CAPTURE));
 	m_ui.OutLatencySpinBox->setEnabled((bOutEnabled && !bNet)
 		|| ((bAlsa || bFreebob || bFirewire) && iAudio != QJACKCTL_CAPTURE));
 
@@ -1117,6 +1121,12 @@ void qjackctlSetupForm::stabilizeForm (void)
 	m_ui.StartMinimizedCheckBox->setEnabled(
 		m_ui.SystemTrayCheckBox->isChecked());
 
+	m_ui.StopJackCheckBox->setEnabled(
+		m_ui.DBusEnabledCheckBox->isChecked());
+	if (!m_ui.DBusEnabledCheckBox->isChecked()) {
+		m_ui.StopJackCheckBox->setChecked(true);
+	}
+
 	bEnabled = m_ui.ServerConfigCheckBox->isChecked();
 	m_ui.ServerConfigNameComboBox->setEnabled(bEnabled);
 	m_ui.ServerConfigTempCheckBox->setEnabled(bEnabled);
@@ -1796,6 +1806,7 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->iConnectionsIconSize     = m_ui.ConnectionsIconSizeComboBox->currentIndex();
 		m_pSetup->sConnectionsFont         = m_ui.ConnectionsFontTextLabel->font().toString();
 		m_pSetup->bStartJack               = m_ui.StartJackCheckBox->isChecked();
+		m_pSetup->bStopJack                = m_ui.StopJackCheckBox->isChecked();
 		m_pSetup->bQueryClose              = m_ui.QueryCloseCheckBox->isChecked();
 		m_pSetup->bKeepOnTop               = m_ui.KeepOnTopCheckBox->isChecked();
 		m_pSetup->bSystemTray              = m_ui.SystemTrayCheckBox->isChecked();
@@ -1818,11 +1829,12 @@ void qjackctlSetupForm::accept (void)
 	}
 
 	// Save combobox history...
-	m_pSetup->saveComboBoxHistory(m_ui.ServerComboBox);
+	m_pSetup->saveComboBoxHistory(m_ui.ServerPrefixComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.ServerNameComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.InterfaceComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.InDeviceComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.OutDeviceComboBox);
+	m_pSetup->saveComboBoxHistory(m_ui.ServerSuffixComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.StartupScriptShellComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.PostStartupScriptShellComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.ShutdownScriptShellComboBox);
