@@ -58,12 +58,10 @@ public:
 
 	void setSocketCaption(const QString& sSocketCaption);
 	void setSocketList(qjackctlSocketList *pSocketList);
+	void setSocketNew(bool bSocketNew);
 
 	void setPixmaps(QPixmap **ppPixmaps);
 
-	void setJackClient(jack_client_t *pJackClient);
-	void setAlsaSeq(snd_seq_t *pAlsaSeq);
-
 	void setConnectCount(int iConnectCount);
 
 	void load(qjackctlPatchbaySocket *pSocket);
@@ -111,8 +109,7 @@ private:
 
 	// Instance variables.
 	qjackctlSocketList *m_pSocketList;
-	jack_client_t      *m_pJackClient;
-	snd_seq_t          *m_pAlsaSeq;
+	bool                m_bSocketNew;
 	QPixmap           **m_ppPixmaps;
 	int                 m_iDirtyCount;
 
